@@ -1,19 +1,26 @@
 package Task::Module::Install::BINGOS;
+$Task::Module::Install::BINGOS::VERSION = '1.04';
+#ABSTRACT: A Task to install all BINGOS' Module::Install extensions
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '1.02';
 
 'BINGOS';
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Task::Module::Install::BINGOS - A Task to install all BINGOS' Module::Install extensions
 
+=head1 VERSION
+
+version 1.04
+
 =head1 SYNOPSIS
 
   perl -MCPANPLUS -e 'install Task::Module::Install::BINGOS'
@@ -43,12 +50,15 @@ The following modules will be installed:
 
   Module::Install::ReadmeFromPod
 
-=head1 LICENSE
-
-This is free software, released under the same terms as perl itself.
-
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
 
-=cut 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
